@@ -1,4 +1,4 @@
-/* epan.h
+/** @file
  *
  * Wireshark Protocol Analyzer Library
  *
@@ -10,23 +10,22 @@
 #ifndef __EPAN_H__
 #define __EPAN_H__
 
+#include <wsutil/feature_list.h>
+#include <epan/tvbuff.h>
+#include <epan/prefs.h>
+#include <epan/frame_data.h>
+#include <epan/register.h>
+#include <wiretap/wtap_opttypes.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
-#include <glib.h>
-#include <epan/tvbuff.h>
-#include <epan/prefs.h>
-#include <epan/frame_data.h>
-#include <wsutil/plugins.h>
-#include <epan/register.h>
-#include "ws_symbol_export.h"
-
-
 /** Global variable holding the content of the corresponding environment variable
  * to save fetching it repeatedly.
  */
-extern gboolean wireshark_abort_on_dissector_bug;
+extern bool wireshark_abort_on_dissector_bug;
+extern bool wireshark_abort_on_too_many_items;
 
 typedef struct epan_dissect epan_dissect_t;
 
@@ -46,16 +45,12 @@ struct packet_provider_data;
  * of libwireshark.
  */
 struct packet_provider_funcs {
-	const nstime_t *(*get_frame_ts)(struct packet_provider_data *prov, guint32 frame_num);
-	const char *(*get_interface_name)(struct packet_provider_data *prov, guint32 interface_id);
-	const char *(*get_interface_description)(struct packet_provider_data *prov, guint32 interface_id);
-	const char *(*get_user_comment)(struct packet_provider_data *prov, const frame_data *fd);
+	const nstime_t *(*get_frame_ts)(struct packet_provider_data *prov, uint32_t frame_num);
+	const char *(*get_interface_name)(struct packet_provider_data *prov, uint32_t interface_id, unsigned section_number);
+	const char *(*get_interface_description)(struct packet_provider_data *prov, uint32_t interface_id, unsigned section_number);
+	wtap_block_t (*get_modified_block)(struct packet_provider_data *prov, const frame_data *fd);
 };
 
-#ifdef HAVE_PLUGINS
-extern plugins_t *libwireshark_plugins;
-#endif
-
 /**
 	@section Epan The Enhanced Packet ANalyzer
 
@@ -103,10 +98,10 @@ Ref2 for further edits - delete when done
  *
  * Must be called only once in a program.
  *
- * Returns TRUE on success, FALSE on failure.
+ * Returns true on success, false on failure.
  */
 WS_DLL_PUBLIC
-gboolean epan_init(register_cb cb, void *client_data, gboolean load_plugins);
+bool epan_init(register_cb cb, void *client_data, bool load_plugins);
 
 /**
  * Load all settings, from the current profile, that affect epan.
@@ -118,19 +113,26 @@ e_prefs *epan_load_settings(void);
 WS_DLL_PUBLIC
 void epan_cleanup(void);
 
-#ifdef HAVE_PLUGINS
 typedef struct {
-	void (*init)(void);
+	void (*init)(void);		/* Called before proto_init() */
+	void (*post_init)(void);	/* Called at the end of epan_init() */
 	void (*dissect_init)(epan_dissect_t *);
 	void (*dissect_cleanup)(epan_dissect_t *);
 	void (*cleanup)(void);
-	void (*register_all_protocols)(register_cb, gpointer);
-	void (*register_all_handoffs)(register_cb, gpointer);
+	void (*register_all_protocols)(register_cb, void *);
+	void (*register_all_handoffs)(register_cb, void *);
 	void (*register_all_tap_listeners)(void);
 } epan_plugin;
 
 WS_DLL_PUBLIC void epan_register_plugin(const epan_plugin *plugin);
-#endif
+
+/** Returns_
+ *     0 if plugins can be loaded for all of libwireshark (tap, dissector, epan).
+ *     1 if plugins are not supported by the platform.
+ *    -1 if plugins were disabled in the build configuration.
+ */
+WS_DLL_PUBLIC int epan_plugins_supported(void);
+
 /**
  * Initialize the table of conversations.  Conversations are identified by
  * their endpoints; they are used for protocols such as IP, TCP, and UDP,
@@ -151,17 +153,17 @@ typedef struct epan_session epan_t;
 WS_DLL_PUBLIC epan_t *epan_new(struct packet_provider_data *prov,
     const struct packet_provider_funcs *funcs);
 
-WS_DLL_PUBLIC const char *epan_get_user_comment(const epan_t *session, const frame_data *fd);
+WS_DLL_PUBLIC wtap_block_t epan_get_modified_block(const epan_t *session, const frame_data *fd);
 
-WS_DLL_PUBLIC const char *epan_get_interface_name(const epan_t *session, guint32 interface_id);
+WS_DLL_PUBLIC const char *epan_get_interface_name(const epan_t *session, uint32_t interface_id, unsigned section_number);
 
-WS_DLL_PUBLIC const char *epan_get_interface_description(const epan_t *session, guint32 interface_id);
+WS_DLL_PUBLIC const char *epan_get_interface_description(const epan_t *session, uint32_t interface_id, unsigned section_number);
 
-const nstime_t *epan_get_frame_ts(const epan_t *session, guint32 frame_num);
+const nstime_t *epan_get_frame_ts(const epan_t *session, uint32_t frame_num);
 
 WS_DLL_PUBLIC void epan_free(epan_t *session);
 
-WS_DLL_PUBLIC const gchar*
+WS_DLL_PUBLIC const char*
 epan_get_version(void);
 
 WS_DLL_PUBLIC void epan_get_version_number(int *major, int *minor, int *micro);
@@ -176,19 +178,20 @@ WS_DLL_PUBLIC void epan_get_version_number(int *major, int *minor, int *micro);
  * created if create_proto_tree is false in the call to epan_dissect_init().
  * Clearing this reverts the decision to epan_dissect_init() and proto_tree_visible.
  */
-void epan_set_always_visible(gboolean force);
+WS_DLL_PUBLIC
+void epan_set_always_visible(bool force);
 
 /** initialize an existing single packet dissection */
 WS_DLL_PUBLIC
 void
-epan_dissect_init(epan_dissect_t *edt, epan_t *session, const gboolean create_proto_tree, const gboolean proto_tree_visible);
+epan_dissect_init(epan_dissect_t *edt, epan_t *session, const bool create_proto_tree, const bool proto_tree_visible);
 
 /** get a new single packet dissection
  * should be freed using epan_dissect_free() after packet dissection completed
  */
 WS_DLL_PUBLIC
 epan_dissect_t*
-epan_dissect_new(epan_t *session, const gboolean create_proto_tree, const gboolean proto_tree_visible);
+epan_dissect_new(epan_t *session, const bool create_proto_tree, const bool proto_tree_visible);
 
 WS_DLL_PUBLIC
 void
@@ -197,7 +200,7 @@ epan_dissect_reset(epan_dissect_t *edt);
 /** Indicate whether we should fake protocols or not */
 WS_DLL_PUBLIC
 void
-epan_dissect_fake_protocols(epan_dissect_t *edt, const gboolean fake_protocols);
+epan_dissect_fake_protocols(epan_dissect_t *edt, const bool fake_protocols);
 
 /** run a single packet dissection */
 WS_DLL_PUBLIC
@@ -241,11 +244,11 @@ epan_dissect_prime_with_hfid_array(epan_dissect_t *edt, GArray *hfids);
 /** fill the dissect run output into the packet list columns */
 WS_DLL_PUBLIC
 void
-epan_dissect_fill_in_columns(epan_dissect_t *edt, const gboolean fill_col_exprs, const gboolean fill_fd_colums);
+epan_dissect_fill_in_columns(epan_dissect_t *edt, const bool fill_col_exprs, const bool fill_fd_colums);
 
 /** Check whether a dissected packet contains a given named field */
 WS_DLL_PUBLIC
-gboolean
+bool
 epan_dissect_packet_contains_field(epan_dissect_t* edt,
                                    const char *field_name);
 
@@ -260,23 +263,23 @@ void
 epan_dissect_free(epan_dissect_t* edt);
 
 /** Sets custom column */
-const gchar *
-epan_custom_set(epan_dissect_t *edt, GSList *ids, gint occurrence,
-				gchar *result, gchar *expr, const int size);
+const char *
+epan_custom_set(epan_dissect_t *edt, GSList *ids, int occurrence,
+				char *result, char *expr, const int size);
 
 /**
  * Get compile-time information for libraries used by libwireshark.
  */
 WS_DLL_PUBLIC
 void
-epan_get_compiled_version_info(GString *str);
+epan_gather_compile_info(feature_list l);
 
 /**
  * Get runtime information for libraries used by libwireshark.
  */
 WS_DLL_PUBLIC
 void
-epan_get_runtime_version_info(GString *str);
+epan_gather_runtime_info(feature_list l);
 
 #ifdef __cplusplus
 }
